Device class

One device entry in a ProbeCompositeTest.devices list. The alias is referenced by OnDevice; target is an optional human-readable device name shown in the generated .probe header and in failure messages.

Constructors

Device(String alias, {String? target})
const

Properties

alias String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited